% Creates a set of basket option prices using Monte-Carlo (interest rate markets)
% Initial rate value
r0=[0.03,0.04,0.04,0.05,0.05];
n=5;
% Default strike/weight for the objective
w0=[.2,.1,.2,.1,.2];
k0=r0*w0';
% Correlation matrix from Brigo and Mercurio p. 301, maturities 1Y, 2Y, 5Y, 7Y, 10Y and vol from p. 311
corrBrigo=[
    1 0.931 0.887 0.822 0.742
    0.931 1 0.657 0.973 0.447
    0.887 0.657 1 0.465 0.968
    0.822 0.973 0.465 1 0.228
    0.742 0.447 0.968 0.228 1];
volsBrigo=[0.185 0.186 0.156 0.141 0.129];
cova=diag(volsBrigo)*corrBrigo*diag(volsBrigo);
% Make it positive definite
cova=cova+1e-4*eye(n);
% Set input weights
inw=zeros(n,n);
for i=1:n
    for j=1:i
        inw(i,j)=1/i;
    end
end
% Simple forwards
q=r0';
% Option forward 
f=inw*r0';
% Strike prices
euc=eye(n);
inw=[inw;inw];
K=[1.1*f',.9*f']';
% Additional options
inw=[inw;w0];
K=[K;1*k0];
% Compute simulated option prices using Monte Carlo
p=[];
for i=1:size(inw,1)
    [price,error]=MCbasket(inw(i,:)',K(i),r0',cova,2,250000);
    p=[p;price];
end
save('SwaptionData');